From 4fa6997925c1976cde4156b61e01489aa243f4b2 Mon Sep 17 00:00:00 2001
From: TsiChungLiew <Tsi-Chung.Liew@freescale.com>
Date: Tue, 14 Aug 2007 03:50:16 -0500
Subject: [PATCH] ColdFire: Add timer struct for M5235 and M5249, and macro definition for interrupt.

Add timer structure for M5235 and M5249 which is different from the rest of CF timer structure. Add macro for interrupt register and peripheral interrupt bit  in dtimer_interrupt().

Signed-off-by: TsiChungLiew <Tsi-Chung.Liew@freescale.com>
---
 include/asm-m68k/immap.h |    2 ++
 include/asm-m68k/timer.h |   16 +++++++++++++++-
 lib_m68k/time.c          |    3 +--
 3 files changed, 18 insertions(+), 3 deletions(-)

diff --git a/include/asm-m68k/immap.h b/include/asm-m68k/immap.h
index 7c267af..2555e7e 100644
--- a/include/asm-m68k/immap.h
+++ b/include/asm-m68k/immap.h
@@ -38,8 +38,10 @@
 #ifdef CONFIG_MCFTMR
 #define CFG_UDELAY_BASE		(MMAP_DTMR0)
 #define CFG_TMR_BASE		(MMAP_DTMR1)
+#define CFG_TMRPND_REG		(((volatile int0_t *)(CFG_INTR_BASE))->iprh0)
 #define CFG_TMRINTR_NO		(INT0_HI_DTMR1)
 #define CFG_TMRINTR_MASK	(INTC_IPRH_INT33)
+#define CFG_TMRINTR_PEND	(CFG_TMRINTR_MASK)
 #define CFG_TMRINTR_PRI		(6)
 #define CFG_TIMER_PRESCALER	(((gd->bus_clk / 1000000) - 1) << 8)
 #endif
diff --git a/include/asm-m68k/timer.h b/include/asm-m68k/timer.h
index d8f4e2a..a678692 100644
--- a/include/asm-m68k/timer.h
+++ b/include/asm-m68k/timer.h
@@ -33,12 +33,26 @@
 /****************************************************************************/
 /* DMA Timer module registers */
 typedef struct dtimer_ctrl {
-	u16 tmr;		/* 0x00 Mode register */
+#if defined(CONFIG_M5249) || defined(CONFIG_M5253)
+        u16 tmr;                /* 0x00 Mode register */
+        u16 res1;               /* 0x02 */
+        u16 trr;                /* 0x04 Reference register */
+        u16 res2;               /* 0x06 */
+        u16 tcr;                /* 0x08 Capture register */
+        u16 res3;               /* 0x0A */
+        u16 tcn;                /* 0x0C Counter register */
+        u16 res4;               /* 0x0E */
+        u8 res6;                /* 0x10 */
+        u8 ter;                 /* 0x11 Event register */
+        u16 res7;               /* 0x12 */
+#else
+ 	u16 tmr;		/* 0x00 Mode register */
 	u8 txmr;		/* 0x02 Extended Mode register */
 	u8 ter;			/* 0x03 Event register */
 	u32 trr;		/* 0x04 Reference register */
 	u32 tcr;		/* 0x08 Capture register */
 	u32 tcn;		/* 0x0C Counter register */
+#endif
 } dtmr_t;
 
 /*Programmable Interrupt Timer */
diff --git a/lib_m68k/time.c b/lib_m68k/time.c
index 3dbce07..6c19059 100644
--- a/lib_m68k/time.c
+++ b/lib_m68k/time.c
@@ -347,10 +347,9 @@ void udelay(unsigned long usec)
 void dtimer_interrupt(void *not_used)
 {
 	volatile dtmr_t *timerp = (dtmr_t *) (CFG_TMR_BASE);
-	volatile int0_t *intp = (int0_t *) (CFG_INTR_BASE);
 
 	/* check for timer interrupt asserted */
-	if ((intp->iprh0 & CFG_TMRINTR_MASK) == CFG_TMRINTR_MASK) {
+	if ((CFG_TMRPND_REG & CFG_TMRINTR_MASK) == CFG_TMRINTR_PEND) {
 		timerp->ter = (DTIM_DTER_CAP | DTIM_DTER_REF);
 		timestamp++;
 		return;
-- 
1.5.2

